# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/intraday_analytics/v1/intraday_ema.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import date_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_date__interval__pb2
from systemathics.apis.type.shared.v1 import sampling_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCsystemathics/apis/services/intraday_analytics/v1/intraday_ema.proto\x12\x30systemathics.apis.services.intraday_analytics.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x34systemathics/apis/type/shared/v1/date_interval.proto\x1a/systemathics/apis/type/shared/v1/sampling.proto\"\xb7\x02\n\x12IntradayEmaRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x46\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.SamplingR\x08sampling\x12S\n\rdate_interval\x18\x03 \x01(\x0b\x32..systemathics.apis.type.shared.v1.DateIntervalR\x0c\x64\x61teInterval\x12\x16\n\x06length\x18\x04 \x01(\x05R\x06length\x12\x1e\n\nadjustment\x18\x05 \x01(\x08R\nadjustment\"l\n\x13IntradayEmaResponse\x12U\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x41.systemathics.apis.services.intraday_analytics.v1.IntradayEmaDataR\x04\x64\x61ta\"|\n\x0fIntradayEmaData\x12\x39\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimeStamp\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value\x12\x18\n\x07\x61verage\x18\x03 \x01(\x01R\x07\x61verage2\xcb\x01\n\x12IntradayEmaService\x12\xb4\x01\n\x0bIntradayEma\x12\x44.systemathics.apis.services.intraday_analytics.v1.IntradayEmaRequest\x1a\x45.systemathics.apis.services.intraday_analytics.v1.IntradayEmaResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/v1/intraday/emab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.intraday_analytics.v1.intraday_ema_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_INTRADAYEMASERVICE'].methods_by_name['IntradayEma']._options = None
  _globals['_INTRADAYEMASERVICE'].methods_by_name['IntradayEma']._serialized_options = b'\202\323\344\223\002\022\022\020/v1/intraday/ema'
  _globals['_INTRADAYEMAREQUEST']._serialized_start=339
  _globals['_INTRADAYEMAREQUEST']._serialized_end=650
  _globals['_INTRADAYEMARESPONSE']._serialized_start=652
  _globals['_INTRADAYEMARESPONSE']._serialized_end=760
  _globals['_INTRADAYEMADATA']._serialized_start=762
  _globals['_INTRADAYEMADATA']._serialized_end=886
  _globals['_INTRADAYEMASERVICE']._serialized_start=889
  _globals['_INTRADAYEMASERVICE']._serialized_end=1092
# @@protoc_insertion_point(module_scope)
