# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/calendar/v1/calendar.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from google.type import timeofday_pb2 as google_dot_type_dot_timeofday__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5systemathics/apis/services/calendar/v1/calendar.proto\x12&systemathics.apis.services.calendar.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x16google/type/date.proto\x1a\x1bgoogle/type/timeofday.proto\x1a\x1bgoogle/protobuf/empty.proto\"\xca\x01\n\x0bHolidayInfo\x12\x12\n\x04\x63ode\x18\x01 \x01(\tR\x04\x63ode\x12\x18\n\x07\x63ountry\x18\x02 \x01(\tR\x07\x63ountry\x12\x1a\n\x08\x63urrency\x18\x03 \x01(\tR\x08\x63urrency\x12G\n\x04type\x18\x04 \x01(\x0e\x32\x33.systemathics.apis.services.calendar.v1.HolidayTypeR\x04type\x12\x12\n\x04mics\x18\x05 \x03(\tR\x04mics\x12\x14\n\x05years\x18\x06 \x03(\x05R\x05years\"p\n\x19HolidayCodeToMicsResponse\x12S\n\x05items\x18\x01 \x03(\x0b\x32=.systemathics.apis.services.calendar.v1.HolidayCodeToMicsItemR\x05items\"N\n\x15HolidayCodeToMicsItem\x12!\n\x0choliday_code\x18\x01 \x01(\tR\x0bholidayCode\x12\x12\n\x04mics\x18\x02 \x03(\tR\x04mics\"J\n\x17TradingHoursDateRequest\x12/\n\x04year\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x04year\"d\n\x18TradingHoursDateResponse\x12\x12\n\x04year\x18\x01 \x01(\x05R\x04year\x12\x34\n\x0ctrading_days\x18\x02 \x03(\x0b\x32\x11.google.type.DateR\x0btradingDays\"e\n\x0fHolidaysRequest\x12!\n\x0choliday_code\x18\x01 \x01(\tR\x0bholidayCode\x12/\n\x04year\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x04year\"}\n\x10HolidaysResponse\x12!\n\x0choliday_code\x18\x01 \x01(\tR\x0bholidayCode\x12\x12\n\x04year\x18\x02 \x01(\x05R\x04year\x12\x32\n\x0b\x63losed_days\x18\x03 \x03(\x0b\x32\x11.google.type.DateR\nclosedDays\"-\n\x17TradingHoursMicResponse\x12\x12\n\x04mics\x18\x01 \x03(\tR\x04mics\"Y\n\x13TradingHoursRequest\x12\x10\n\x03mic\x18\x01 \x01(\tR\x03mic\x12\x30\n\ntrade_date\x18\x02 \x01(\x0b\x32\x11.google.type.DateR\ttradeDate\"\xc9\n\n\tMicRecord\x12\x10\n\x03mic\x18\x01 \x01(\tR\x03mic\x12T\n\x08mic_type\x18\x02 \x01(\x0e\x32\x39.systemathics.apis.services.calendar.v1.MicRecord.MicTypeR\x07micType\x12#\n\roperating_mic\x18\x03 \x01(\tR\x0coperatingMic\x12 \n\x0b\x64\x65scription\x18\x04 \x01(\tR\x0b\x64\x65scription\x12*\n\x11legal_entity_name\x18\x05 \x01(\tR\x0flegalEntityName\x12\x36\n\x17legal_entity_identifier\x18\x06 \x01(\tR\x15legalEntityIdentifier\x12p\n\x14market_category_code\x18\x07 \x01(\x0e\x32>.systemathics.apis.services.calendar.v1.MicRecord.CategoryCodeR\x12marketCategoryCode\x12\x36\n\x07\x61\x63ronym\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x07\x61\x63ronym\x12(\n\x10iso_country_code\x18\t \x01(\tR\x0eisoCountryCode\x12\x12\n\x04\x63ity\x18\n \x01(\tR\x04\x63ity\x12\x36\n\x07website\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x07website\x12S\n\x06status\x18\x0c \x01(\x0e\x32;.systemathics.apis.services.calendar.v1.MicRecord.MicStatusR\x06status\x12\x36\n\rcreation_date\x18\r \x01(\x0b\x32\x11.google.type.DateR\x0c\x63reationDate\x12;\n\x10last_update_date\x18\x0e \x01(\x0b\x32\x11.google.type.DateR\x0elastUpdateDate\x12\x43\n\x14last_validation_date\x18\x0f \x01(\x0b\x32\x11.google.type.DateR\x12lastValidationDate\x12\x32\n\x0b\x65xpiry_date\x18\x10 \x01(\x0b\x32\x11.google.type.DateR\nexpiryDate\x12\x36\n\x07\x63omment\x18\x11 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x07\x63omment\x12\x1b\n\ttime_zone\x18\x12 \x01(\tR\x08timeZone\"P\n\x07MicType\x12\x18\n\x14MIC_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11MIC_TYPE_OPERATOR\x10\x01\x12\x14\n\x10MIC_TYPE_SEGMENT\x10\x02\"\xae\x01\n\x0c\x43\x61tegoryCode\x12\x08\n\x04NSPD\x10\x00\x12\x08\n\x04\x41TSS\x10\x01\x12\x08\n\x04\x41PPA\x10\x02\x12\x08\n\x04\x41RMS\x10\x03\x12\x08\n\x04\x43TPS\x10\x04\x12\x08\n\x04\x43\x41SP\x10\x05\x12\x08\n\x04\x44\x43MS\x10\x06\x12\x08\n\x04IDQS\x10\x07\x12\x08\n\x04MLTF\x10\x08\x12\x08\n\x04OTFS\x10\t\x12\x08\n\x04OTHR\x10\n\x12\x08\n\x04RMOS\x10\x0b\x12\x08\n\x04RMKT\x10\x0c\x12\x08\n\x04SEFS\x10\r\x12\x08\n\x04SINT\x10\x0e\x12\x08\n\x04TRFS\x10\x0f\"n\n\tMicStatus\x12\x1a\n\x16MIC_STATUS_UNSPECIFIED\x10\x00\x12\x15\n\x11MIC_STATUS_ACTIVE\x10\x01\x12\x16\n\x12MIC_STATUS_EXPIRED\x10\x02\x12\x16\n\x12MIC_STATUS_UPDATED\x10\x03\"\xe0\x02\n\x13TradingHoursMessage\x12\x10\n\x03mic\x18\x01 \x01(\tR\x03mic\x12\x30\n\ntrade_date\x18\x02 \x01(\x0b\x32\x11.google.type.DateR\ttradeDate\x12=\n\x0eorder_accepted\x18\x03 \x01(\x0b\x32\x16.google.type.TimeOfDayR\rorderAccepted\x12\x35\n\nearly_open\x18\x04 \x01(\x0b\x32\x16.google.type.TimeOfDayR\tearlyOpen\x12*\n\x04open\x18\x05 \x01(\x0b\x32\x16.google.type.TimeOfDayR\x04open\x12,\n\x05\x63lose\x18\x06 \x01(\x0b\x32\x16.google.type.TimeOfDayR\x05\x63lose\x12\x35\n\nlate_close\x18\x07 \x01(\x0b\x32\x16.google.type.TimeOfDayR\tlateClose*v\n\x0bHolidayType\x12\x1c\n\x18HOLIDAY_TYPE_UNSPECIFIED\x10\x00\x12 \n\x1cHOLIDAY_TYPE_FUTURES_TRADING\x10\x01\x12\'\n#HOLIDAY_TYPE_STOCK_EXCHANGE_TRADING\x10\x02\x32\xc2\x08\n\x0f\x43\x61lendarService\x12~\n\x0eGetHolidayCode\x12\x16.google.protobuf.Empty\x1a\x33.systemathics.apis.services.calendar.v1.HolidayInfo\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v1/calendar/holidays0\x01\x12\x98\x01\n\x11HolidayCodeToMics\x12\x16.google.protobuf.Empty\x1a\x41.systemathics.apis.services.calendar.v1.HolidayCodeToMicsResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /v1/calendar/holiday_code_2_mics\x12\x9c\x01\n\x08Holidays\x12\x37.systemathics.apis.services.calendar.v1.HolidaysRequest\x1a\x38.systemathics.apis.services.calendar.v1.HolidaysResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v1/calendar/holidays\x12\x93\x01\n\x0fTradingHoursMic\x12\x16.google.protobuf.Empty\x1a?.systemathics.apis.services.calendar.v1.TradingHoursMicResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/calendar/trading_hours/mics\x12\xc0\x01\n\x11TradingHoursDates\x12?.systemathics.apis.services.calendar.v1.TradingHoursDateRequest\x1a@.systemathics.apis.services.calendar.v1.TradingHoursDateResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /v1/calendar/trading_hours/dates\x12m\n\x03Mic\x12\x16.google.protobuf.Empty\x1a\x31.systemathics.apis.services.calendar.v1.MicRecord\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/v1/calendar/mics0\x01\x12\xac\x01\n\x0cTradingHours\x12;.systemathics.apis.services.calendar.v1.TradingHoursRequest\x1a;.systemathics.apis.services.calendar.v1.TradingHoursMessage\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1/calendar/trading_hoursb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.calendar.v1.calendar_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CALENDARSERVICE'].methods_by_name['GetHolidayCode']._options = None
  _globals['_CALENDARSERVICE'].methods_by_name['GetHolidayCode']._serialized_options = b'\202\323\344\223\002\027\022\025/v1/calendar/holidays'
  _globals['_CALENDARSERVICE'].methods_by_name['HolidayCodeToMics']._options = None
  _globals['_CALENDARSERVICE'].methods_by_name['HolidayCodeToMics']._serialized_options = b'\202\323\344\223\002\"\022 /v1/calendar/holiday_code_2_mics'
  _globals['_CALENDARSERVICE'].methods_by_name['Holidays']._options = None
  _globals['_CALENDARSERVICE'].methods_by_name['Holidays']._serialized_options = b'\202\323\344\223\002\027\022\025/v1/calendar/holidays'
  _globals['_CALENDARSERVICE'].methods_by_name['TradingHoursMic']._options = None
  _globals['_CALENDARSERVICE'].methods_by_name['TradingHoursMic']._serialized_options = b'\202\323\344\223\002!\022\037/v1/calendar/trading_hours/mics'
  _globals['_CALENDARSERVICE'].methods_by_name['TradingHoursDates']._options = None
  _globals['_CALENDARSERVICE'].methods_by_name['TradingHoursDates']._serialized_options = b'\202\323\344\223\002\"\022 /v1/calendar/trading_hours/dates'
  _globals['_CALENDARSERVICE'].methods_by_name['Mic']._options = None
  _globals['_CALENDARSERVICE'].methods_by_name['Mic']._serialized_options = b'\202\323\344\223\002\023\022\021/v1/calendar/mics'
  _globals['_CALENDARSERVICE'].methods_by_name['TradingHours']._options = None
  _globals['_CALENDARSERVICE'].methods_by_name['TradingHours']._serialized_options = b'\202\323\344\223\002\034\022\032/v1/calendar/trading_hours'
  _globals['_HOLIDAYTYPE']._serialized_start=2897
  _globals['_HOLIDAYTYPE']._serialized_end=3015
  _globals['_HOLIDAYINFO']._serialized_start=242
  _globals['_HOLIDAYINFO']._serialized_end=444
  _globals['_HOLIDAYCODETOMICSRESPONSE']._serialized_start=446
  _globals['_HOLIDAYCODETOMICSRESPONSE']._serialized_end=558
  _globals['_HOLIDAYCODETOMICSITEM']._serialized_start=560
  _globals['_HOLIDAYCODETOMICSITEM']._serialized_end=638
  _globals['_TRADINGHOURSDATEREQUEST']._serialized_start=640
  _globals['_TRADINGHOURSDATEREQUEST']._serialized_end=714
  _globals['_TRADINGHOURSDATERESPONSE']._serialized_start=716
  _globals['_TRADINGHOURSDATERESPONSE']._serialized_end=816
  _globals['_HOLIDAYSREQUEST']._serialized_start=818
  _globals['_HOLIDAYSREQUEST']._serialized_end=919
  _globals['_HOLIDAYSRESPONSE']._serialized_start=921
  _globals['_HOLIDAYSRESPONSE']._serialized_end=1046
  _globals['_TRADINGHOURSMICRESPONSE']._serialized_start=1048
  _globals['_TRADINGHOURSMICRESPONSE']._serialized_end=1093
  _globals['_TRADINGHOURSREQUEST']._serialized_start=1095
  _globals['_TRADINGHOURSREQUEST']._serialized_end=1184
  _globals['_MICRECORD']._serialized_start=1187
  _globals['_MICRECORD']._serialized_end=2540
  _globals['_MICRECORD_MICTYPE']._serialized_start=2171
  _globals['_MICRECORD_MICTYPE']._serialized_end=2251
  _globals['_MICRECORD_CATEGORYCODE']._serialized_start=2254
  _globals['_MICRECORD_CATEGORYCODE']._serialized_end=2428
  _globals['_MICRECORD_MICSTATUS']._serialized_start=2430
  _globals['_MICRECORD_MICSTATUS']._serialized_end=2540
  _globals['_TRADINGHOURSMESSAGE']._serialized_start=2543
  _globals['_TRADINGHOURSMESSAGE']._serialized_end=2895
  _globals['_CALENDARSERVICE']._serialized_start=3018
  _globals['_CALENDARSERVICE']._serialized_end=4108
# @@protoc_insertion_point(module_scope)
