# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/static_data/v1/static_data.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from google.type import timeofday_pb2 as google_dot_type_dot_timeofday__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import asset_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_asset__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;systemathics/apis/services/static_data/v1/static_data.proto\x12)systemathics.apis.services.static_data.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x16google/type/date.proto\x1a\x1bgoogle/type/timeofday.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a,systemathics/apis/type/shared/v1/asset.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"\xde\x0c\n\x17StaticDataSearchRequest\x12J\n\nasset_type\x18\x01 \x01(\x0e\x32+.systemathics.apis.type.shared.v1.AssetTypeR\tassetType\x12\x14\n\x05start\x18\x02 \x01(\x05R\x05start\x12\x14\n\x05\x63ount\x18\x03 \x01(\x05R\x05\x63ount\x12\x34\n\x06ticker\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x06ticker\x12\x38\n\x08\x65xchange\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x08\x65xchange\x12\x32\n\x06\x61\x63tive\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x06\x61\x63tive\x12\x36\n\x07primary\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x07primary\x12:\n\toperating\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\toperating\x12\x30\n\x04name\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x04name\x12\x38\n\x08\x63urrency\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x08\x63urrency\x12\x36\n\x07\x63ountry\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x07\x63ountry\x12:\n\tbloomberg\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.StringValueR\tbloomberg\x12\x36\n\x07reuters\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x07reuters\x12>\n\x0bmorningstar\x18\x0e \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0bmorningstar\x12\x34\n\x06markit\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x06markit\x12\x30\n\x04\x66igi\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x04\x66igi\x12\x43\n\x0e\x63omposite_figi\x18\x11 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\rcompositeFigi\x12=\n\x0bshared_figi\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\nsharedFigi\x12\x30\n\x04isin\x18\x13 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x04isin\x12\x32\n\x05sedol\x18\x14 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x05sedol\x12\x38\n\x08\x63ontract\x18\x15 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x08\x63ontract\x12\x32\n\x05\x63usip\x18\x16 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x05\x63usip\x12>\n\x0b\x64\x65scription\x18\x17 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0b\x64\x65scription\x12\x34\n\x06sector\x18\x18 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x06sector\x12<\n\nunderlying\x18\x19 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\nunderlying\x12U\n\x08maturity\x18\x1a \x01(\x0b\x32\x39.systemathics.apis.services.static_data.v1.StaticDataDateR\x08maturity\x12`\n\x0e\x63\x61pitalization\x18\x1b \x01(\x0b\x32\x38.systemathics.apis.services.static_data.v1.StaticDataIntR\x0e\x63\x61pitalization\x12.\n\x03\x63ik\x18\x1c \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x03\x63ik\"\x9c\x01\n\x0eStaticDataDate\x12)\n\x05\x65xact\x18\x01 \x01(\x0b\x32\x11.google.type.DateH\x00R\x05\x65xact\x12V\n\x05range\x18\x02 \x01(\x0b\x32>.systemathics.apis.services.static_data.v1.StaticDataDateRangeH\x00R\x05rangeB\x07\n\x05oneof\"\x8b\x01\n\x13StaticDataDateRange\x12.\n\tless_than\x18\x01 \x01(\x0b\x32\x11.google.type.DateR\x08lessThan\x12\x44\n\x15greater_or_equal_than\x18\x02 \x01(\x0b\x32\x11.google.type.DateR\x12greaterOrEqualThan\"\x8d\x01\n\x10StaticDataDouble\x12\x16\n\x05\x65xact\x18\x01 \x01(\x01H\x00R\x05\x65xact\x12X\n\x05range\x18\x02 \x01(\x0b\x32@.systemathics.apis.services.static_data.v1.StaticDataDoubleRangeH\x00R\x05rangeB\x07\n\x05oneof\"\xa3\x01\n\x15StaticDataDoubleRange\x12\x39\n\tless_than\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x08lessThan\x12O\n\x15greater_or_equal_than\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x12greaterOrEqualThan\"\x87\x01\n\rStaticDataInt\x12\x16\n\x05\x65xact\x18\x01 \x01(\x03H\x00R\x05\x65xact\x12U\n\x05range\x18\x02 \x01(\x0b\x32=.systemathics.apis.services.static_data.v1.StaticDataIntRangeH\x00R\x05rangeB\x07\n\x05oneof\"\x9e\x01\n\x12StaticDataIntRange\x12\x38\n\tless_than\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x08lessThan\x12N\n\x15greater_or_equal_than\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x12greaterOrEqualThan\"\x8d\x02\n\x12StaticDataResponse\x12Q\n\x06\x66uture\x18\x01 \x01(\x0b\x32\x39.systemathics.apis.services.static_data.v1.FutureResponseR\x06\x66uture\x12Q\n\x06\x65quity\x18\x02 \x01(\x0b\x32\x39.systemathics.apis.services.static_data.v1.EquityResponseR\x06\x65quity\x12Q\n\x06\x63rypto\x18\x03 \x01(\x0b\x32\x39.systemathics.apis.services.static_data.v1.CryptoResponseR\x06\x63rypto\"\x81\x01\n\x0e\x43ryptoResponse\x12N\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x36.systemathics.apis.services.static_data.v1.CryptoEntryR\x06\x61ssets\x12\x1f\n\x0btotal_count\x18\x02 \x01(\x03R\ntotalCount\"\x81\x01\n\x0e\x45quityResponse\x12N\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x36.systemathics.apis.services.static_data.v1.EquityEntryR\x06\x61ssets\x12\x1f\n\x0btotal_count\x18\x02 \x01(\x03R\ntotalCount\"\x81\x01\n\x0e\x46utureResponse\x12N\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x36.systemathics.apis.services.static_data.v1.FutureEntryR\x06\x61ssets\x12\x1f\n\x0btotal_count\x18\x02 \x01(\x03R\ntotalCount\"\xb8\x0b\n\x0b\x45quityEntry\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12%\n\x04\x64\x61te\x18\x02 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12\x12\n\x04type\x18\x03 \x01(\tR\x04type\x12\x16\n\x06\x61\x63tive\x18\x04 \x01(\x08R\x06\x61\x63tive\x12\x18\n\x07primary\x18\x05 \x01(\tR\x07primary\x12\x1c\n\toperating\x18\x06 \x01(\tR\toperating\x12\x12\n\x04name\x18\x07 \x01(\tR\x04name\x12\x1a\n\x08\x63urrency\x18\x08 \x01(\tR\x08\x63urrency\x12\x18\n\x07\x63ountry\x18\t \x01(\tR\x07\x63ountry\x12Y\n\x0etick_size_rule\x18\n \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.TickSizeR\x0ctickSizeRule\x12\x14\n\x05index\x18\x0b \x03(\tR\x05index\x12\x1a\n\x08\x63\x61lendar\x18\x0c \x01(\tR\x08\x63\x61lendar\x12 \n\x0b\x64\x65scription\x18\r \x01(\tR\x0b\x64\x65scription\x12*\n\x04open\x18\x0e \x01(\x0b\x32\x16.google.type.TimeOfDayR\x04open\x12,\n\x05\x63lose\x18\x0f \x01(\x0b\x32\x16.google.type.TimeOfDayR\x05\x63lose\x12\x1b\n\ttime_zone\x18\x10 \x01(\tR\x08timeZone\x12\x19\n\x08lot_size\x18\x11 \x01(\x03R\x07lotSize\x12\x1f\n\x0bpoint_value\x18\x12 \x01(\x01R\npointValue\x12\x14\n\x05price\x18\x13 \x01(\x01R\x05price\x12\x16\n\x06volume\x18\x14 \x01(\x03R\x06volume\x12\x18\n\x07sources\x18\x15 \x01(\x05R\x07sources\x12]\n\x07mapping\x18\x16 \x03(\x0b\x32\x43.systemathics.apis.services.static_data.v1.EquityEntry.MappingEntryR\x07mapping\x12\x1c\n\tbloomberg\x18\x17 \x01(\tR\tbloomberg\x12\x18\n\x07reuters\x18\x18 \x01(\tR\x07reuters\x12!\n\x0cmorning_star\x18\x19 \x01(\tR\x0bmorningStar\x12\x16\n\x06markit\x18\x1a \x01(\tR\x06markit\x12\x12\n\x04\x66igi\x18\x1b \x01(\tR\x04\x66igi\x12%\n\x0e\x63omposite_figi\x18\x1c \x01(\tR\rcompositeFigi\x12\x12\n\x04isin\x18\x1d \x01(\tR\x04isin\x12\x14\n\x05\x63usip\x18\x1e \x01(\tR\x05\x63usip\x12\x14\n\x05sedol\x18\x1f \x01(\tR\x05sedol\x12&\n\x0e\x63lassification\x18  \x01(\tR\x0e\x63lassification\x12\x10\n\x03\x63ik\x18! \x01(\tR\x03\x63ik\x12]\n\x07sectors\x18\" \x03(\x0b\x32\x43.systemathics.apis.services.static_data.v1.EquityEntry.SectorsEntryR\x07sectors\x12&\n\x0e\x63\x61pitalization\x18# \x01(\x03R\x0e\x63\x61pitalization\x12\x18\n\x07\x61\x64\x64ress\x18$ \x01(\tR\x07\x61\x64\x64ress\x12\x14\n\x05phone\x18% \x01(\tR\x05phone\x12\x14\n\x05\x65mail\x18& \x01(\tR\x05\x65mail\x12\x10\n\x03url\x18\' \x01(\tR\x03url\x1a:\n\x0cMappingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a:\n\x0cSectorsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xd5\x0b\n\x0b\x46utureEntry\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12%\n\x04\x64\x61te\x18\x02 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12\x12\n\x04type\x18\x03 \x01(\tR\x04type\x12\x16\n\x06\x61\x63tive\x18\x04 \x01(\x08R\x06\x61\x63tive\x12\x18\n\x07primary\x18\x05 \x01(\tR\x07primary\x12\x1c\n\toperating\x18\x06 \x01(\tR\toperating\x12\x12\n\x04name\x18\x07 \x01(\tR\x04name\x12\x1a\n\x08\x63urrency\x18\x08 \x01(\tR\x08\x63urrency\x12\x18\n\x07\x63ountry\x18\t \x01(\tR\x07\x63ountry\x12Y\n\x0etick_size_rule\x18\n \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.TickSizeR\x0ctickSizeRule\x12\x14\n\x05index\x18\x0b \x03(\tR\x05index\x12\x1a\n\x08\x63\x61lendar\x18\x0c \x01(\tR\x08\x63\x61lendar\x12 \n\x0b\x64\x65scription\x18\r \x01(\tR\x0b\x64\x65scription\x12*\n\x04open\x18\x0e \x01(\x0b\x32\x16.google.type.TimeOfDayR\x04open\x12,\n\x05\x63lose\x18\x0f \x01(\x0b\x32\x16.google.type.TimeOfDayR\x05\x63lose\x12\x1b\n\ttime_zone\x18\x10 \x01(\tR\x08timeZone\x12\x19\n\x08lot_size\x18\x11 \x01(\x03R\x07lotSize\x12\x1f\n\x0bpoint_value\x18\x12 \x01(\x01R\npointValue\x12\x14\n\x05price\x18\x13 \x01(\x01R\x05price\x12\x16\n\x06volume\x18\x14 \x01(\x03R\x06volume\x12\x18\n\x07sources\x18\x15 \x01(\x05R\x07sources\x12]\n\x07mapping\x18\x16 \x03(\x0b\x32\x43.systemathics.apis.services.static_data.v1.FutureEntry.MappingEntryR\x07mapping\x12\x1c\n\tbloomberg\x18\x17 \x01(\tR\tbloomberg\x12\x18\n\x07reuters\x18\x18 \x01(\tR\x07reuters\x12!\n\x0cmorning_star\x18\x19 \x01(\tR\x0bmorningStar\x12\x16\n\x06markit\x18\x1a \x01(\tR\x06markit\x12\x12\n\x04\x66igi\x18\x1b \x01(\tR\x04\x66igi\x12%\n\x0e\x63omposite_figi\x18\x1c \x01(\tR\rcompositeFigi\x12\x12\n\x04isin\x18\x1d \x01(\tR\x04isin\x12\x14\n\x05\x63usip\x18\x1e \x01(\tR\x05\x63usip\x12\x14\n\x05sedol\x18\x1f \x01(\tR\x05sedol\x12&\n\x0e\x63lassification\x18  \x01(\tR\x0e\x63lassification\x12\x1e\n\nunderlying\x18! \x01(\tR\nunderlying\x12\x1a\n\x08\x63ontract\x18\" \x01(\tR\x08\x63ontract\x12`\n\x08\x63\x61tegory\x18# \x03(\x0b\x32\x44.systemathics.apis.services.static_data.v1.FutureEntry.CategoryEntryR\x08\x63\x61tegory\x12\x14\n\x05\x63hain\x18$ \x01(\tR\x05\x63hain\x12-\n\x08maturity\x18% \x01(\x0b\x32\x11.google.type.DateR\x08maturity\x12\x14\n\x05month\x18& \x01(\tR\x05month\x12\x12\n\x04year\x18\' \x01(\x05R\x04year\x1a:\n\x0cMappingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a;\n\rCategoryEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xa4\x0b\n\x0b\x43ryptoEntry\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12%\n\x04\x64\x61te\x18\x02 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12\x12\n\x04type\x18\x03 \x01(\tR\x04type\x12\x16\n\x06\x61\x63tive\x18\x04 \x01(\x08R\x06\x61\x63tive\x12\x18\n\x07primary\x18\x05 \x01(\tR\x07primary\x12\x1c\n\toperating\x18\x06 \x01(\tR\toperating\x12\x12\n\x04name\x18\x07 \x01(\tR\x04name\x12#\n\rbase_currency\x18\x08 \x01(\tR\x0c\x62\x61seCurrency\x12\x18\n\x07\x63ountry\x18\t \x01(\tR\x07\x63ountry\x12Y\n\x0etick_size_rule\x18\n \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.TickSizeR\x0ctickSizeRule\x12\x14\n\x05index\x18\x0b \x03(\tR\x05index\x12\x1a\n\x08\x63\x61lendar\x18\x0c \x01(\tR\x08\x63\x61lendar\x12 \n\x0b\x64\x65scription\x18\r \x01(\tR\x0b\x64\x65scription\x12*\n\x04open\x18\x0e \x01(\x0b\x32\x16.google.type.TimeOfDayR\x04open\x12,\n\x05\x63lose\x18\x0f \x01(\x0b\x32\x16.google.type.TimeOfDayR\x05\x63lose\x12\x1b\n\ttime_zone\x18\x10 \x01(\tR\x08timeZone\x12\x19\n\x08lot_size\x18\x11 \x01(\x03R\x07lotSize\x12\x1f\n\x0bpoint_value\x18\x12 \x01(\x01R\npointValue\x12\x14\n\x05price\x18\x13 \x01(\x01R\x05price\x12\x16\n\x06volume\x18\x14 \x01(\x03R\x06volume\x12\x18\n\x07sources\x18\x15 \x01(\x05R\x07sources\x12]\n\x07mapping\x18\x16 \x03(\x0b\x32\x43.systemathics.apis.services.static_data.v1.CryptoEntry.MappingEntryR\x07mapping\x12\x1c\n\tbloomberg\x18\x17 \x01(\tR\tbloomberg\x12\x18\n\x07reuters\x18\x18 \x01(\tR\x07reuters\x12!\n\x0cmorning_star\x18\x19 \x01(\tR\x0bmorningStar\x12\x16\n\x06markit\x18\x1a \x01(\tR\x06markit\x12\x12\n\x04\x66igi\x18\x1b \x01(\tR\x04\x66igi\x12%\n\x0e\x63omposite_figi\x18\x1c \x01(\tR\rcompositeFigi\x12\x12\n\x04isin\x18\x1d \x01(\tR\x04isin\x12\x14\n\x05\x63usip\x18\x1e \x01(\tR\x05\x63usip\x12\x14\n\x05sedol\x18\x1f \x01(\tR\x05sedol\x12&\n\x0e\x63lassification\x18  \x01(\tR\x0e\x63lassification\x12%\n\x0equote_currency\x18! \x01(\tR\rquoteCurrency\x12\x1c\n\tconsensus\x18\" \x03(\tR\tconsensus\x12\x30\n\nissue_date\x18# \x01(\x0b\x32\x11.google.type.DateR\tissueDate\x12&\n\x0e\x63\x61pitalization\x18$ \x01(\x03R\x0e\x63\x61pitalization\x12-\n\x12\x63irculating_supply\x18% \x01(\x03R\x11\x63irculatingSupply\x12\x1d\n\nmax_supply\x18& \x01(\x03R\tmaxSupply\x12!\n\x0ctotal_supply\x18\' \x01(\x03R\x0btotalSupply\x1a:\n\x0cMappingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"z\n\x15StaticDataIdentifiers\x12\x61\n\x0bidentifiers\x18\x01 \x03(\x0b\x32?.systemathics.apis.services.static_data.v1.StaticDataIdentifierR\x0bidentifiers\"\x8b\x01\n\x14StaticDataIdentifier\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12%\n\x04\x64\x61te\x18\x02 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\"4\n\x08TickSize\x12\x14\n\x05price\x18\x01 \x01(\x01R\x05price\x12\x12\n\x04tick\x18\x02 \x01(\x01R\x04tick*\x86\x02\n\rFrequencyType\x12\x1e\n\x1a\x46REQUENCY_TYPE_UNSPECIFIED\x10\x00\x12\x17\n\x13\x46REQUENCY_TYPE_NONE\x10\x01\x12\x16\n\x12\x46REQUENCY_TYPE_DAY\x10\x02\x12\x17\n\x13\x46REQUENCY_TYPE_WEEK\x10\x03\x12\x18\n\x14\x46REQUENCY_TYPE_MONTH\x10\x04\x12\x1a\n\x16\x46REQUENCY_TYPE_QUARTER\x10\x05\x12\x1d\n\x19\x46REQUENCY_TYPE_SEMIANNUAL\x10\x06\x12\x19\n\x15\x46REQUENCY_TYPE_ANNUAL\x10\x07\x12\x1b\n\x17\x46REQUENCY_TYPE_BIANNUAL\x10\x08*\x81\x01\n\x0c\x45xerciseType\x12\x1d\n\x19\x45XERCISE_TYPE_UNSPECIFIED\x10\x00\x12\x1a\n\x16\x45XERCISE_TYPE_AMERICAN\x10\x01\x12\x1a\n\x16\x45XERCISE_TYPE_EUROPEAN\x10\x02\x12\x1a\n\x16\x45XERCISE_TYPE_BERMUDAN\x10\x03*\xed\x01\n\x0f\x43ouponFrequency\x12 \n\x1c\x43OUPON_FREQUENCY_UNSPECIFIED\x10\x00\x12\x1b\n\x17\x43OUPON_FREQUENCY_ANNUAL\x10\x01\x12 \n\x1c\x43OUPON_FREQUENCY_SEMI_ANNUAL\x10\x02\x12\x1d\n\x19\x43OUPON_FREQUENCY_QUATERLY\x10\x04\x12\x1f\n\x1b\x43OUPON_FREQUENCY_BI_MONTHLY\x10\x06\x12\x1c\n\x18\x43OUPON_FREQUENCY_MONTHLY\x10\x0c\x12\x1b\n\x17\x43OUPON_FREQUENCY_WEEKLY\x10\x34*\xe1\x10\n\x08\x44\x61yCount\x12\x19\n\x15\x44\x41Y_COUNT_UNSPECIFIED\x10\x00\x12\x15\n\x11\x44\x41Y_COUNT_ACT_ACT\x10\x01\x12\x15\n\x11\x44\x41Y_COUNT_ACT_360\x10\x02\x12\x15\n\x11\x44\x41Y_COUNT_ACT_365\x10\x03\x12\x14\n\x10\x44\x41Y_COUNT_30_ACT\x10\x04\x12\x14\n\x10\x44\x41Y_COUNT_30_360\x10\x05\x12\x14\n\x10\x44\x41Y_COUNT_30_365\x10\x06\x12\x14\n\x10\x44\x41Y_COUNT_NL_ACT\x10\x07\x12\x14\n\x10\x44\x41Y_COUNT_NL_360\x10\x08\x12\x14\n\x10\x44\x41Y_COUNT_NL_365\x10\t\x12\x1d\n\x19\x44\x41Y_COUNT_ACT_ACT_NON_EOM\x10\n\x12\x1d\n\x19\x44\x41Y_COUNT_ACT_360_NON_EOM\x10\x0b\x12\x1d\n\x19\x44\x41Y_COUNT_ACT_365_NON_EOM\x10\x0c\x12\x1c\n\x18\x44\x41Y_COUNT_30_ACT_NON_EOM\x10\r\x12\x1c\n\x18\x44\x41Y_COUNT_30_360_NON_EOM\x10\x0e\x12\x1c\n\x18\x44\x41Y_COUNT_30_365_NON_EOM\x10\x0f\x12\x1c\n\x18\x44\x41Y_COUNT_NL_ACT_NON_EOM\x10\x10\x12\x1c\n\x18\x44\x41Y_COUNT_NL_360_NON_EOM\x10\x11\x12\x1c\n\x18\x44\x41Y_COUNT_NL_365_NON_EOM\x10\x12\x12\x19\n\x15\x44\x41Y_COUNT_ISMA_30_ACT\x10\x13\x12\x19\n\x15\x44\x41Y_COUNT_ISMA_30_360\x10\x14\x12\x19\n\x15\x44\x41Y_COUNT_ISMA_30_365\x10\x15\x12 \n\x1c\x44\x41Y_COUNT_ISMA30_ACT_NON_EOM\x10\x16\x12 \n\x1c\x44\x41Y_COUNT_ISMA_30_360_NONEOM\x10\x17\x12 \n\x1c\x44\x41Y_COUNT_ISMA30_365_NON_EOM\x10\x18\x12\x15\n\x11\x44\x41Y_COUNT_ACT_364\x10\x1b\x12\x18\n\x14\x44\x41Y_COUNT_ACT_365_66\x10\x1c\x12\x1c\n\x18\x44\x41Y_COUNT_US_MUNI_30_360\x10\x1d\x12\x1d\n\x19\x44\x41Y_COUNT_ACT_364_NON_EOM\x10\x1e\x12 \n\x1c\x44\x41Y_COUNT_MUNI30_360_NON_EOM\x10 \x12\x1a\n\x16\x44\x41Y_COUNT_BUS_DAYS_252\x10!\x12\x1b\n\x17\x44\x41Y_COUNT_GERMAN_30_360\x10#\x12 \n\x1c\x44\x41Y_COUNT_BUS_DAY_252NON_EOM\x10$\x12 \n\x1c\x44\x41Y_COUNT_ACT_365_66_NON_EOM\x10%\x12 \n\x1c\x44\x41Y_COUNT_GER_30_360_NON_EOM\x10&\x12\x1c\n\x18\x44\x41Y_COUNT_US_WIT_ACT_ACT\x10(\x12\x1c\n\x18\x44\x41Y_COUNT_US_WIB_ACT_360\x10)\x12\x1f\n\x1b\x44\x41Y_COUNT_ISDA_SWAPS_30_360\x10,\x12\x1f\n\x1b\x44\x41Y_COUNT_ISDA_SWAPS_30_365\x10-\x12 \n\x1c\x44\x41Y_COUNT_ISDA30_360_NON_EOM\x10/\x12 \n\x1c\x44\x41Y_COUNT_ISDA30_365_NON_EOM\x10\x30\x12 \n\x1c\x44\x41Y_COUNT_ISDA30_ACT_NON_EOM\x10\x31\x12\x1a\n\x16\x44\x41Y_COUNT_ISDA_30E_360\x10\x32\x12\x1a\n\x16\x44\x41Y_COUNT_ISDA_30E_365\x10\x33\x12\x1a\n\x16\x44\x41Y_COUNT_ISDA_30E_ACT\x10\x34\x12 \n\x1c\x44\x41Y_COUNT_ISDA_30E_360_N_EOM\x10\x35\x12 \n\x1c\x44\x41Y_COUNT_ISDA_30E_365_N_EOM\x10\x36\x12\x1a\n\x16\x44\x41Y_COUNT_ISDA_ACT_ACT\x10:\x12 \n\x1c\x44\x41Y_COUNT_ISDA_ACT_ACT_N_EOM\x10=\x12\x14\n\x10\x44\x41Y_COUNT_28_360\x10>\x12\x14\n\x10\x44\x41Y_COUNT_BD_252\x10\x63\x12\x19\n\x15\x44\x41Y_COUNT_ACT_ACT_101\x10\x65\x12\x19\n\x15\x44\x41Y_COUNT_ACT_360_102\x10\x66\x12\x19\n\x15\x44\x41Y_COUNT_ACT_365_103\x10g\x12\x18\n\x14\x44\x41Y_COUNT_30_360_104\x10h\x12\x1d\n\x19\x44\x41Y_COUNT_ACT_ACT_NOM_105\x10i\x12\x1d\n\x19\x44\x41Y_COUNT_ACT_360_NOM_106\x10j\x12\x1d\n\x19\x44\x41Y_COUNT_ACT_365_NOM_107\x10k\x12\x1e\n\x19\x44\x41Y_COUNT_ISMA_30_360_131\x10\x83\x01\x12\x1f\n\x1a\x44\x41Y_COUNT_ISDA_ACT_ACT_201\x10\xc9\x01\x12\x1e\n\x19\x44\x41Y_COUNT_AFB_ACT_ACT_202\x10\xca\x01\x12#\n\x1e\x44\x41Y_COUNT_ISDA_ACT_ACT_NOM_203\x10\xcb\x01\x12\"\n\x1d\x44\x41Y_COUNT_AFB_ACT_ACT_NOM_204\x10\xcc\x01\x12 \n\x1b\x44\x41Y_COUNT_ISMA_ACT_ACT__206\x10\xce\x01\x12#\n\x1e\x44\x41Y_COUNT_ISMA_ACT_ACT_NOM_207\x10\xcf\x01\x12\x1b\n\x16\x44\x41Y_COUNT_BUSINESS_252\x10\xfc\x01\x12\x16\n\x11\x44\x41Y_COUNT_30E_360\x10\xde\x07\x12\x16\n\x11\x44\x41Y_COUNT_30E_365\x10\xdf\x07\x12\x16\n\x11\x44\x41Y_COUNT_30E_ACT\x10\xe0\x07\x12\x16\n\x11\x44\x41Y_COUNT_30G_360\x10\xe1\x07\x12\x16\n\x11\x44\x41Y_COUNT_301_360\x10\xe2\x07\x12\x16\n\x11\x44\x41Y_COUNT_301_365\x10\xe3\x07\x12\x16\n\x11\x44\x41Y_COUNT_30I_ACT\x10\xe4\x07\x12\x16\n\x11\x44\x41Y_COUNT_30M_360\x10\xe5\x07*b\n\x0cSwaptionType\x12\x1d\n\x19SWAPTION_TYPE_UNSPECIFIED\x10\x00\x12\x17\n\x13SWAPTION_TYPE_PAYER\x10\x01\x12\x1a\n\x16SWAPTION_TYPE_RECEIVER\x10\x02\x32\xf3\x02\n\x11StaticDataService\x12\xa3\x01\n\x06Search\x12\x42.systemathics.apis.services.static_data.v1.StaticDataSearchRequest\x1a=.systemathics.apis.services.static_data.v1.StaticDataResponse\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/v1/staticdata\x12\xb7\x01\n\x10GetByIdentifiers\x12@.systemathics.apis.services.static_data.v1.StaticDataIdentifiers\x1a=.systemathics.apis.services.static_data.v1.StaticDataResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1/staticdata/identifiersb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.static_data.v1.static_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_EQUITYENTRY_MAPPINGENTRY']._options = None
  _globals['_EQUITYENTRY_MAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_EQUITYENTRY_SECTORSENTRY']._options = None
  _globals['_EQUITYENTRY_SECTORSENTRY']._serialized_options = b'8\001'
  _globals['_FUTUREENTRY_MAPPINGENTRY']._options = None
  _globals['_FUTUREENTRY_MAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_FUTUREENTRY_CATEGORYENTRY']._options = None
  _globals['_FUTUREENTRY_CATEGORYENTRY']._serialized_options = b'8\001'
  _globals['_CRYPTOENTRY_MAPPINGENTRY']._options = None
  _globals['_CRYPTOENTRY_MAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_STATICDATASERVICE'].methods_by_name['Search']._options = None
  _globals['_STATICDATASERVICE'].methods_by_name['Search']._serialized_options = b'\202\323\344\223\002\020\022\016/v1/staticdata'
  _globals['_STATICDATASERVICE'].methods_by_name['GetByIdentifiers']._options = None
  _globals['_STATICDATASERVICE'].methods_by_name['GetByIdentifiers']._serialized_options = b'\202\323\344\223\002\034\022\032/v1/staticdata/identifiers'
  _globals['_FREQUENCYTYPE']._serialized_start=8260
  _globals['_FREQUENCYTYPE']._serialized_end=8522
  _globals['_EXERCISETYPE']._serialized_start=8525
  _globals['_EXERCISETYPE']._serialized_end=8654
  _globals['_COUPONFREQUENCY']._serialized_start=8657
  _globals['_COUPONFREQUENCY']._serialized_end=8894
  _globals['_DAYCOUNT']._serialized_start=8897
  _globals['_DAYCOUNT']._serialized_end=11042
  _globals['_SWAPTIONTYPE']._serialized_start=11044
  _globals['_SWAPTIONTYPE']._serialized_end=11142
  _globals['_STATICDATASEARCHREQUEST']._serialized_start=319
  _globals['_STATICDATASEARCHREQUEST']._serialized_end=1949
  _globals['_STATICDATADATE']._serialized_start=1952
  _globals['_STATICDATADATE']._serialized_end=2108
  _globals['_STATICDATADATERANGE']._serialized_start=2111
  _globals['_STATICDATADATERANGE']._serialized_end=2250
  _globals['_STATICDATADOUBLE']._serialized_start=2253
  _globals['_STATICDATADOUBLE']._serialized_end=2394
  _globals['_STATICDATADOUBLERANGE']._serialized_start=2397
  _globals['_STATICDATADOUBLERANGE']._serialized_end=2560
  _globals['_STATICDATAINT']._serialized_start=2563
  _globals['_STATICDATAINT']._serialized_end=2698
  _globals['_STATICDATAINTRANGE']._serialized_start=2701
  _globals['_STATICDATAINTRANGE']._serialized_end=2859
  _globals['_STATICDATARESPONSE']._serialized_start=2862
  _globals['_STATICDATARESPONSE']._serialized_end=3131
  _globals['_CRYPTORESPONSE']._serialized_start=3134
  _globals['_CRYPTORESPONSE']._serialized_end=3263
  _globals['_EQUITYRESPONSE']._serialized_start=3266
  _globals['_EQUITYRESPONSE']._serialized_end=3395
  _globals['_FUTURERESPONSE']._serialized_start=3398
  _globals['_FUTURERESPONSE']._serialized_end=3527
  _globals['_EQUITYENTRY']._serialized_start=3530
  _globals['_EQUITYENTRY']._serialized_end=4994
  _globals['_EQUITYENTRY_MAPPINGENTRY']._serialized_start=4876
  _globals['_EQUITYENTRY_MAPPINGENTRY']._serialized_end=4934
  _globals['_EQUITYENTRY_SECTORSENTRY']._serialized_start=4936
  _globals['_EQUITYENTRY_SECTORSENTRY']._serialized_end=4994
  _globals['_FUTUREENTRY']._serialized_start=4997
  _globals['_FUTUREENTRY']._serialized_end=6490
  _globals['_FUTUREENTRY_MAPPINGENTRY']._serialized_start=4876
  _globals['_FUTUREENTRY_MAPPINGENTRY']._serialized_end=4934
  _globals['_FUTUREENTRY_CATEGORYENTRY']._serialized_start=6431
  _globals['_FUTUREENTRY_CATEGORYENTRY']._serialized_end=6490
  _globals['_CRYPTOENTRY']._serialized_start=6493
  _globals['_CRYPTOENTRY']._serialized_end=7937
  _globals['_CRYPTOENTRY_MAPPINGENTRY']._serialized_start=4876
  _globals['_CRYPTOENTRY_MAPPINGENTRY']._serialized_end=4934
  _globals['_STATICDATAIDENTIFIERS']._serialized_start=7939
  _globals['_STATICDATAIDENTIFIERS']._serialized_end=8061
  _globals['_STATICDATAIDENTIFIER']._serialized_start=8064
  _globals['_STATICDATAIDENTIFIER']._serialized_end=8203
  _globals['_TICKSIZE']._serialized_start=8205
  _globals['_TICKSIZE']._serialized_end=8257
  _globals['_STATICDATASERVICE']._serialized_start=11145
  _globals['_STATICDATASERVICE']._serialized_end=11516
# @@protoc_insertion_point(module_scope)
