# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/option_type.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2systemathics/apis/type/shared/v1/option_type.proto\x12 systemathics.apis.type.shared.v1*T\n\nOptionType\x12\x1b\n\x17OPTION_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10OPTION_TYPE_CALL\x10\x01\x12\x13\n\x0fOPTION_TYPE_PUT\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.type.shared.v1.option_type_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_OPTIONTYPE']._serialized_start=88
  _globals['_OPTIONTYPE']._serialized_end=172
# @@protoc_insertion_point(module_scope)
