# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/calendar/v1/trading_hours.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from systemathics.apis.services.calendar.v1 import calendar_pb2 as systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:systemathics/apis/services/calendar/v1/trading_hours.proto\x12&systemathics.apis.services.calendar.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x35systemathics/apis/services/calendar/v1/calendar.proto\"z\n\x16SetTradingHoursRequest\x12`\n\rtrading_hours\x18\x01 \x03(\x0b\x32;.systemathics.apis.services.calendar.v1.TradingHoursMessageR\x0ctradingHours2\xa5\x01\n\x13TradingHoursService\x12\x8d\x01\n\x0fSetTradingHours\x12>.systemathics.apis.services.calendar.v1.SetTradingHoursRequest\x1a\x16.google.protobuf.Empty\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/v1/calendar/trading_hoursb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.calendar.v1.trading_hours_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TRADINGHOURSSERVICE'].methods_by_name['SetTradingHours']._options = None
  _globals['_TRADINGHOURSSERVICE'].methods_by_name['SetTradingHours']._serialized_options = b'\202\323\344\223\002\034\"\032/v1/calendar/trading_hours'
  _globals['_SETTRADINGHOURSREQUEST']._serialized_start=216
  _globals['_SETTRADINGHOURSREQUEST']._serialized_end=338
  _globals['_TRADINGHOURSSERVICE']._serialized_start=341
  _globals['_TRADINGHOURSSERVICE']._serialized_end=506
# @@protoc_insertion_point(module_scope)
